# FreeDATA

    FreeDATA is a versatile, open-source platform designed specifically for HF communications, leveraging Codec2 data modes for robust global digital communication. It features a network-based server-client architecture, a REST API, multi-platform compatibility, and a messaging system.

[![CodeFactor](https://www.codefactor.io/repository/github/dj2ls/freedata/badge)](https://www.codefactor.io/repository/github/dj2ls/freedata)

Please keep in mind, this project is still under development with many issues which need to be solved.

![FreeDATA_main_screen.png](documentation%2FFreeDATA_main_screen.png)

![FreeDATA_chat_screen.png](documentation%2FFreeDATA_chat_screen.png)

## Installation

Please check the [wiki](https://wiki.freedata.app) for installation instructions
Please check the ['Releases'](https://github.com/DJ2LS/FreeDATA/releases) section for downloading precompiled builds

## Credits

- David Rowe and the FreeDV team for developing the modem and libraries -
  FreeDV Codec 2 : https://github.com/drowe67/codec2
